@@ -1,6 +1,8 @@
 ## evaluate the process model density function
 
 dprocess.internal <- function (object, x, times, params, log = FALSE, .getnativesymbolinfo = TRUE, ...) {
+    storage.mode(x) <- "double"
+    storage.mode(params) <- "double"
     pompLoad(object)
     rv <- .Call(do_dprocess,object,x,times,params,log,.getnativesymbolinfo)
     pompUnload(object)
